@@ -16,8 +16,8 @@ pub(crate) const MAGIC_COMMENT_KIND_SIZE: usize = 4;
 pub(crate) const MAGIC_COMMENT_SIZE: usize = 40;
 pub(crate) const DIAGNOSTIC_MESSAGE_SIZE: usize = 40;
 pub(crate) const NODE_ALIAS_SIZE: usize = 48;
-pub(crate) const NODE_AND_ASGN_SIZE: usize = 48;
 pub(crate) const NODE_AND_SIZE: usize = 48;
+pub(crate) const NODE_AND_ASGN_SIZE: usize = 48;
 pub(crate) const NODE_ARG_SIZE: usize = 32;
 pub(crate) const NODE_ARGS_SIZE: usize = 88;
 pub(crate) const NODE_ARRAY_SIZE: usize = 88;
@@ -26,8 +26,8 @@ pub(crate) const NODE_ARRAY_PATTERN_WITH_TAIL_SIZE: usize = 88;
 pub(crate) const NODE_BACK_REF_SIZE: usize = 32;
 pub(crate) const NODE_BEGIN_SIZE: usize = 88;
 pub(crate) const NODE_BLOCK_SIZE: usize = 72;
-pub(crate) const NODE_BLOCK_PASS_SIZE: usize = 40;
 pub(crate) const NODE_BLOCKARG_SIZE: usize = 64;
+pub(crate) const NODE_BLOCK_PASS_SIZE: usize = 40;
 pub(crate) const NODE_BREAK_SIZE: usize = 56;
 pub(crate) const NODE_CASE_SIZE: usize = 112;
 pub(crate) const NODE_CASE_MATCH_SIZE: usize = 112;
@@ -60,24 +60,22 @@ pub(crate) const NODE_FORWARDED_ARGS_SIZE: usize = 16;
 pub(crate) const NODE_GVAR_SIZE: usize = 32;
 pub(crate) const NODE_GVASGN_SIZE: usize = 80;
 pub(crate) const NODE_HASH_SIZE: usize = 88;
-pub(crate) const NODE_KWARGS_SIZE: usize = 40;
 pub(crate) const NODE_HASH_PATTERN_SIZE: usize = 88;
 pub(crate) const NODE_HEREDOC_SIZE: usize = 72;
 pub(crate) const NODE_IF_SIZE: usize = 120;
 pub(crate) const NODE_IF_GUARD_SIZE: usize = 40;
+pub(crate) const NODE_I_FLIP_FLOP_SIZE: usize = 48;
 pub(crate) const NODE_IF_MOD_SIZE: usize = 56;
 pub(crate) const NODE_IF_TERNARY_SIZE: usize = 72;
-pub(crate) const NODE_I_FLIP_FLOP_SIZE: usize = 48;
-pub(crate) const NODE_MATCH_PATTERN_SIZE: usize = 48;
-pub(crate) const NODE_MATCH_PATTERN_P_SIZE: usize = 48;
-pub(crate) const NODE_IN_PATTERN_SIZE: usize = 72;
 pub(crate) const NODE_INDEX_SIZE: usize = 80;
 pub(crate) const NODE_INDEX_ASGN_SIZE: usize = 112;
+pub(crate) const NODE_IN_PATTERN_SIZE: usize = 72;
 pub(crate) const NODE_INT_SIZE: usize = 56;
 pub(crate) const NODE_IRANGE_SIZE: usize = 48;
 pub(crate) const NODE_IVAR_SIZE: usize = 32;
 pub(crate) const NODE_IVASGN_SIZE: usize = 80;
 pub(crate) const NODE_KWARG_SIZE: usize = 48;
+pub(crate) const NODE_KWARGS_SIZE: usize = 40;
 pub(crate) const NODE_KW_BEGIN_SIZE: usize = 88;
 pub(crate) const NODE_KWNILARG_SIZE: usize = 32;
 pub(crate) const NODE_KWOPTARG_SIZE: usize = 56;
@@ -92,6 +90,8 @@ pub(crate) const NODE_MATCH_ALT_SIZE: usize = 48;
 pub(crate) const NODE_MATCH_AS_SIZE: usize = 48;
 pub(crate) const NODE_MATCH_CURRENT_LINE_SIZE: usize = 24;
 pub(crate) const NODE_MATCH_NIL_PATTERN_SIZE: usize = 48;
+pub(crate) const NODE_MATCH_PATTERN_SIZE: usize = 48;
+pub(crate) const NODE_MATCH_PATTERN_P_SIZE: usize = 48;
 pub(crate) const NODE_MATCH_REST_SIZE: usize = 40;
 pub(crate) const NODE_MATCH_VAR_SIZE: usize = 48;
 pub(crate) const NODE_MATCH_WITH_LVASGN_SIZE: usize = 48;
@@ -112,15 +112,15 @@ pub(crate) const NODE_PREEXE_SIZE: usize = 72;
 pub(crate) const NODE_PROCARG0_SIZE: usize = 88;
 pub(crate) const NODE_RATIONAL_SIZE: usize = 56;
 pub(crate) const NODE_REDO_SIZE: usize = 16;
-pub(crate) const NODE_REG_OPT_SIZE: usize = 32;
 pub(crate) const NODE_REGEXP_SIZE: usize = 80;
+pub(crate) const NODE_REG_OPT_SIZE: usize = 32;
 pub(crate) const NODE_RESCUE_SIZE: usize = 80;
 pub(crate) const NODE_RESCUE_BODY_SIZE: usize = 104;
 pub(crate) const NODE_RESTARG_SIZE: usize = 72;
 pub(crate) const NODE_RETRY_SIZE: usize = 16;
 pub(crate) const NODE_RETURN_SIZE: usize = 56;
 pub(crate) const NODE_S_CLASS_SIZE: usize = 80;
-pub(crate) const NODE_SELF_SIZE: usize = 16;
+pub(crate) const NODE_SELF__SIZE: usize = 16;
 pub(crate) const NODE_SEND_SIZE: usize = 184;
 pub(crate) const NODE_SHADOWARG_SIZE: usize = 32;
 pub(crate) const NODE_SPLAT_SIZE: usize = 40;
