@@ -1,4 +1,4 @@
-use crate::lexer::{ParseIdent, ParseString, TokAdd, Yylval};
+use crate::lexer::TokAdd;
 use crate::maybe_byte::MaybeByte;
 use crate::source::buffer::*;
 use crate::str_term::{str_types::*, HeredocEnd, HeredocLiteral, StrTerm};
@@ -6,22 +6,10 @@ use crate::Lexer;
 use crate::TokenBuf;
 use crate::{lex_states::*, DiagnosticMessage};
 
-pub(crate) trait ParseHeredoc {
-    fn heredoc_identifier(&mut self) -> Option<i32>;
-    fn here_document(&mut self) -> i32;
-    fn compute_heredoc_end(&self) -> HeredocEnd;
-    fn here_document_error(&mut self, here: &HeredocLiteral, eos: usize, len: usize) -> i32;
-    fn here_document_restore(&mut self, here: &HeredocLiteral) -> i32;
-    fn heredoc_flush_str(&mut self, str_: &TokenBuf) -> i32;
-    fn heredoc_flush(&mut self) -> i32;
-    fn heredoc_restore(&mut self, here: &HeredocLiteral);
-    fn update_heredoc_indent(&mut self, c: &MaybeByte) -> bool;
-}
-
 const TAB_WIDTH: i32 = 8;
 
-impl ParseHeredoc for Lexer {
-    fn heredoc_identifier(&mut self) -> Option<i32> {
+impl Lexer {
+    pub(crate) fn heredoc_identifier(&mut self) -> Option<i32> {
         /*
          * term_len is length of `<<"END"` except `END`,
          * in this case term_len is 4 (<, <, " and ").
@@ -75,7 +63,7 @@ impl ParseHeredoc for Lexer {
             }
         } else {
             if !self.is_identchar() {
-                self.buffer.pushback(&c);
+                self.buffer.pushback(c);
                 if (func & STR_FUNC_INDENT) != 0 {
                     self.buffer.pushback(if indent > 0 { b'~' } else { b'-' });
                 }
@@ -93,7 +81,7 @@ impl ParseHeredoc for Lexer {
                     break;
                 }
             }
-            self.buffer.pushback(&c);
+            self.buffer.pushback(c);
         }
 
         len = self.buffer.pcur - (self.buffer.pbeg + offset) - quote;
@@ -109,14 +97,14 @@ impl ParseHeredoc for Lexer {
 
         self.buffer.goto_eol();
 
-        self.strterm = Some(StrTerm::new_heredoc(HeredocLiteral::new(
+        self.strterm = Some(Box::new(StrTerm::new_heredoc(HeredocLiteral::new(
             self.buffer.lastline,
             offset,
             self.buffer.ruby_sourceline,
             len,
             quote,
             func,
-        )));
+        ))));
 
         self.token_flush();
         self.buffer.heredoc_indent = indent;
@@ -124,8 +112,8 @@ impl ParseHeredoc for Lexer {
         Some(token)
     }
 
-    fn here_document(&mut self) -> i32 {
-        let here = match self.strterm.as_ref().unwrap() {
+    pub(crate) fn here_document(&mut self) -> i32 {
+        let here = match self.strterm.as_ref().unwrap().as_ref() {
             StrTerm::StringLiteral(_) => unreachable!("strterm must be heredoc"),
             StrTerm::HeredocLiteral(h) => h.clone(),
         };
@@ -162,8 +150,7 @@ impl ParseHeredoc for Lexer {
              */
             self.buffer.heredoc_line_indent = 0;
         } else if self.buffer.is_whole_match(
-            &self
-                .buffer
+            self.buffer
                 .substr_at(eos, eos + len)
                 .expect("failed to get heredoc id for comparison"),
             indent,
@@ -194,15 +181,14 @@ impl ParseHeredoc for Lexer {
 
                 if self.buffer.heredoc_indent > 0 {
                     let mut i = 0;
-                    while (ptr + i < ptr_end) && self.update_heredoc_indent(&self.char_at(ptr + i))
-                    {
+                    while (ptr + i < ptr_end) && self.update_heredoc_indent(self.char_at(ptr + i)) {
                         i += 1;
                     }
                     self.buffer.heredoc_line_indent = 0;
                 }
 
                 match self.buffer.substr_at(ptr, ptr_end) {
-                    Some(s) => str_.append(&s),
+                    Some(s) => str_.append(s),
                     _ => panic!(
                         "no substr {}..{} (len = {})",
                         ptr,
@@ -223,8 +209,7 @@ impl ParseHeredoc for Lexer {
                 }
 
                 if self.buffer.is_whole_match(
-                    &self
-                        .buffer
+                    self.buffer
                         .substr_at(eos, eos + len)
                         .expect("failed to get heredoc id for comparison"),
                     indent,
@@ -251,7 +236,7 @@ impl ParseHeredoc for Lexer {
                 c = self.nextc();
             }
             loop {
-                self.buffer.pushback(&c);
+                self.buffer.pushback(c);
                 // enc = self.p.enc;
                 match self.tokadd_string(func, b'\n', None, &mut 0) {
                     Some(cc) => c = cc,
@@ -270,7 +255,7 @@ impl ParseHeredoc for Lexer {
                     return self.heredoc_flush();
                 }
                 let cc = self.nextc();
-                self.tokadd(&cc);
+                self.tokadd(cc);
                 if self.buffer.heredoc_indent > 0 {
                     self.buffer.goto_eol();
                     return self.heredoc_flush();
@@ -281,8 +266,7 @@ impl ParseHeredoc for Lexer {
                 }
 
                 if self.buffer.is_whole_match(
-                    &self
-                        .buffer
+                    self.buffer
                         .substr_at(eos, eos + len)
                         .expect("failed to get heredoc id for comparison"),
                     indent,
@@ -329,7 +313,7 @@ impl ParseHeredoc for Lexer {
     }
 
     fn here_document_error(&mut self, here: &HeredocLiteral, eos: usize, len: usize) -> i32 {
-        self.heredoc_restore(&here);
+        self.heredoc_restore(here);
         self.compile_error(
             DiagnosticMessage::new_unterminated_heredoc(
                 String::from_utf8_lossy(
@@ -354,7 +338,7 @@ impl ParseHeredoc for Lexer {
         self.lval_end = Some(heredoc_end.end);
         self.set_yylval_str(&TokenBuf::new(&heredoc_end.value));
 
-        self.heredoc_restore(&here);
+        self.heredoc_restore(here);
         self.token_flush();
         self.strterm = None;
         self.lex_state.set(EXPR_END);
@@ -389,19 +373,19 @@ impl ParseHeredoc for Lexer {
         self.buffer.eofp = false;
     }
 
-    fn update_heredoc_indent(&mut self, c: &MaybeByte) -> bool {
+    pub(crate) fn update_heredoc_indent(&mut self, c: MaybeByte) -> bool {
         if self.buffer.heredoc_line_indent == -1 {
-            if *c == b'\n' {
+            if c == b'\n' {
                 self.buffer.heredoc_line_indent = 0
             }
-        } else if *c == b' ' {
+        } else if c == b' ' {
             self.buffer.heredoc_line_indent += 1;
             return true;
-        } else if *c == b'\t' {
+        } else if c == b'\t' {
             let w = (self.buffer.heredoc_line_indent / TAB_WIDTH) + 1;
             self.buffer.heredoc_line_indent = w * TAB_WIDTH;
             return true;
-        } else if *c != b'\n' {
+        } else if c != b'\n' {
             if self.buffer.heredoc_indent > self.buffer.heredoc_line_indent {
                 self.buffer.heredoc_indent = self.buffer.heredoc_line_indent
             }
