@@ -4,7 +4,9 @@ use crate::source::{MagicComment, MagicCommentKind};
 use crate::DiagnosticMessage;
 use crate::Lexer;
 
-const MAGIC_COMMENTS: &[(&str, fn() -> MagicCommentKind)] = &[
+type MagicCommentData = (&'static str, fn() -> MagicCommentKind);
+
+const MAGIC_COMMENTS: &[MagicCommentData] = &[
     ("coding", MagicCommentKind::encoding),
     ("encoding", MagicCommentKind::encoding),
     (
@@ -18,15 +20,8 @@ const MAGIC_COMMENTS: &[(&str, fn() -> MagicCommentKind)] = &[
     ("warn_indent", MagicCommentKind::warn_indent),
 ];
 
-pub(crate) trait ParseMagicComment {
-    fn comment_at_top(&self) -> bool;
-    fn set_file_encoding(&mut self, str_: usize, send: usize);
-    fn magic_comment_marker(&self, str_: usize, len: usize) -> usize;
-    fn magic_comment(&mut self, str_: usize, len: usize) -> Result<bool, ()>;
-}
-
-impl ParseMagicComment for Lexer {
-    fn comment_at_top(&self) -> bool {
+impl Lexer {
+    pub(crate) fn comment_at_top(&self) -> bool {
         let mut ptr = self.buffer.pbeg;
         let ptr_end = self.buffer.pcur - 1;
         if self.buffer.line_count != (if self.buffer.has_shebang { 2 } else { 1 }) {
@@ -41,7 +36,7 @@ impl ParseMagicComment for Lexer {
         true
     }
 
-    fn set_file_encoding(&mut self, mut str_: usize, send: usize) {
+    pub(crate) fn set_file_encoding(&mut self, mut str_: usize, send: usize) {
         let mut sep = false;
         let beg;
 
@@ -49,7 +44,7 @@ impl ParseMagicComment for Lexer {
             if send - str_ <= 6 {
                 return;
             }
-            match self.char_at(str_ + 6).to_option() {
+            match self.char_at(str_ + 6).as_option() {
                 Some(b'C') | Some(b'c') => {
                     str_ += 6;
                     continue;
@@ -130,7 +125,7 @@ impl ParseMagicComment for Lexer {
         let mut i = 2;
 
         while i < len {
-            match self.char_at(str_ + i).to_option() {
+            match self.char_at(str_ + i).as_option() {
                 Some(b'-') => {
                     if self.char_at(str_ + i - 1) == b'*' && self.char_at(str_ + i - 2) == b'-' {
                         return str_ + i + 1;
@@ -155,7 +150,7 @@ impl ParseMagicComment for Lexer {
         0
     }
 
-    fn magic_comment(&mut self, mut str_: usize, mut len: usize) -> Result<bool, ()> {
+    pub(crate) fn magic_comment(&mut self, mut str_: usize, mut len: usize) -> Result<bool, ()> {
         let mut indicator = false;
         let mut name;
         let mut beg;
@@ -205,7 +200,7 @@ impl ParseMagicComment for Lexer {
 
             beg = str_;
             loop {
-                if !(len > 0) {
+                if len <= 0 {
                     break;
                 }
 
@@ -339,7 +334,7 @@ impl ParseMagicComment for Lexer {
                                     DiagnosticMessage::new_encoding_error(
                                         format!(
                                             "unknown encoding name: {}",
-                                            String::from_utf8_lossy(&err.as_bytes())
+                                            String::from_utf8_lossy(err.as_bytes())
                                         )
                                         .into(),
                                     ),
