@@ -1,7 +1,6 @@
 crate::use_native_or_external!(Maybe);
 
 use super::ParserOptions;
-use crate::debug_level;
 
 const DEFAULT_BUFFER_NAME: &str = "(eval)";
 
@@ -9,7 +8,6 @@ impl Default for ParserOptions {
     fn default() -> Self {
         Self::new(
             DEFAULT_BUFFER_NAME.to_string().into(),
-            debug_level::NONE,
             Maybe::none(),
             Maybe::none(),
             true,
