@@ -16,18 +16,18 @@ extern "C" {
         input_error: Blob<InputError>,
     ) -> Blob<DecoderResult>;
     fn lib_ruby_parser__external__decoder_result__drop(blob: *mut Blob<DecoderResult>);
-    fn lib_ruby_parser__external__decoder_result_is_ok(blob: *const Blob<DecoderResult>) -> bool;
-    fn lib_ruby_parser__external__decoder_result_is_err(blob: *const Blob<DecoderResult>) -> bool;
-    fn lib_ruby_parser__external__decoder_result_into_ok(
+    fn lib_ruby_parser__external__decoder_result__is_ok(blob: *const Blob<DecoderResult>) -> bool;
+    fn lib_ruby_parser__external__decoder_result__is_err(blob: *const Blob<DecoderResult>) -> bool;
+    fn lib_ruby_parser__external__decoder_result__into_ok(
         blob: Blob<DecoderResult>,
     ) -> Blob<List<u8>>;
-    fn lib_ruby_parser__external__decoder_result_into_err(
+    fn lib_ruby_parser__external__decoder_result__into_err(
         blob: Blob<DecoderResult>,
     ) -> Blob<InputError>;
-    fn lib_ruby_parser__external__decoder_result_as_ok(
+    fn lib_ruby_parser__external__decoder_result__as_ok(
         blob: *const Blob<DecoderResult>,
     ) -> *const Blob<List<u8>>;
-    fn lib_ruby_parser__external__decoder_result_as_err(
+    fn lib_ruby_parser__external__decoder_result__as_err(
         blob: *const Blob<DecoderResult>,
     ) -> *const Blob<InputError>;
 }
@@ -50,16 +50,16 @@ impl DecoderResult {
     }
 
     pub(crate) fn is_ok(&self) -> bool {
-        unsafe { lib_ruby_parser__external__decoder_result_is_ok(&self.blob) }
+        unsafe { lib_ruby_parser__external__decoder_result__is_ok(&self.blob) }
     }
 
     pub(crate) fn is_err(&self) -> bool {
-        unsafe { lib_ruby_parser__external__decoder_result_is_err(&self.blob) }
+        unsafe { lib_ruby_parser__external__decoder_result__is_err(&self.blob) }
     }
 
     pub(crate) fn as_ok(&self) -> &List<u8> {
         unsafe {
-            (lib_ruby_parser__external__decoder_result_as_ok(&self.blob) as *const List<u8>)
+            (lib_ruby_parser__external__decoder_result__as_ok(&self.blob) as *const List<u8>)
                 .as_ref()
                 .unwrap()
         }
@@ -67,7 +67,7 @@ impl DecoderResult {
 
     pub(crate) fn as_err(&self) -> &InputError {
         unsafe {
-            (lib_ruby_parser__external__decoder_result_as_err(&self.blob) as *const InputError)
+            (lib_ruby_parser__external__decoder_result__as_err(&self.blob) as *const InputError)
                 .as_ref()
                 .unwrap()
         }
@@ -75,13 +75,13 @@ impl DecoderResult {
 
     pub(crate) fn unwrap_ok(self) -> List<u8> {
         let list_blob =
-            unsafe { lib_ruby_parser__external__decoder_result_into_ok(self.into_blob()) };
+            unsafe { lib_ruby_parser__external__decoder_result__into_ok(self.into_blob()) };
         List::from_blob(list_blob)
     }
 
     pub(crate) fn unwrap_err(self) -> InputError {
         let input_error_blob =
-            unsafe { lib_ruby_parser__external__decoder_result_into_err(self.into_blob()) };
+            unsafe { lib_ruby_parser__external__decoder_result__into_err(self.into_blob()) };
         InputError::from_blob(input_error_blob)
     }
 
