@@ -25,7 +25,7 @@ impl Finder {
                 result: None,
             },
         };
-        visitor.visit_root(&root);
+        visitor.visit_root(root);
         Ok(visitor.observer.result)
     }
 }
@@ -45,3 +45,6 @@ impl Observer for Finder {
         self.current_path.pop().unwrap();
     }
 }
+
+#[cfg(test)]
+mod tests;
